==> airbridge_flutter_sdk-1.0.0.tar.gz: ios/Classes/AFLDeeplinkAPI.m <==
//
//  AFLDeeplinkAPI.m
//  airbridge_flutter_sdk
//
//  Created by WOF on 08/10/2019.
//

#import "AFLDeeplinkAPI.h"

// Airbridge
#import "AirBridge.h"
// AB
#import "ABGet.h"

@interface AFLDeeplinkAPI () <FlutterStreamHandler>

@end

@implementation AFLDeeplinkAPI

static NSString* initialDeeplink;
static NSString* initialDeferredDeeplink;

+ (void) setInitialDeeplinkCallback {
    [AirBridge.deeplink setDeeplinkCallback:^(NSString* deeplink) {
        initialDeeplink = deeplink;
    }];
    [AirBridge.deeplink setDeferredDeeplinkCallback:^(NSString* deeplink) {
        initialDeferredDeeplink = deeplink;
    }];
}

//
// flutter plugin setting
//

+ (void) registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
    AFLDeeplinkAPI* deeplinkAPI = [[AFLDeeplinkAPI alloc] init];
    
    FlutterEventChannel* deeplinkEvent
    = [FlutterEventChannel eventChannelWithName:@"airbridge_flutter_sdk/event/deeplink"
                                binaryMessenger:registrar.messenger];
    [deeplinkEvent setStreamHandler:deeplinkAPI];
    
    FlutterEventChannel* deferredDeeplinkEvent
    = [FlutterEventChannel eventChannelWithName:@"airbridge_flutter_sdk/event/deferred_deeplink"
                                binaryMessenger:registrar.messenger];
    [deferredDeeplinkEvent setStreamHandler:deeplinkAPI];
}

- (FlutterError *)onListenWithArguments:(id)arguments eventSink:(FlutterEventSink)events {
    NSString* target = [ABGet type:NSString.class object:arguments];
    if (target == nil || events == nil) {
        return nil;
    }
    
    if ([target isEqualToString:@"deeplink"]) {
        if (initialDeeplink != nil) {
            events(initialDeeplink);
            initialDeeplink = nil;
        }

        [AirBridge.deeplink setDeeplinkCallback:^(NSString* deeplink) {
            events(deeplink);
        }];
    } else if ([target isEqualToString:@"deferred_deeplink"]) {
        if (initialDeferredDeeplink != nil) {
            events(initialDeferredDeeplink);
            initialDeferredDeeplink = nil;
        }

        [AirBridge.deeplink setDeferredDeeplinkCallback:^(NSString* deeplink) {
            events(deeplink);
        }];
    }
    
    return nil;
}

- (FlutterError *)onCancelWithArguments:(id)arguments {
    NSString* target = [ABGet type:NSString.class object:arguments];
    if (target == nil) {
        return nil;
    }
    
    if ([target isEqualToString:@"deeplink"]) {
        [AirBridge.deeplink setDeeplinkCallback:^(NSString* deeplink) {}];
    } else if ([target isEqualToString:@"deferred_deeplink"]) {
        [AirBridge.deeplink setDeferredDeeplinkCallback:^(NSString* deeplink) {}];
    }
    
    return nil;
}

@end

==> airbridge_flutter_sdk-1.1.0.tar.gz: ios/Classes/AFLDeeplinkAPI.m <==
//
//  AFLDeeplinkAPI.m
//  airbridge_flutter_sdk
//
//  Created by WOF on 08/10/2019.
//

#import "AFLDeeplinkAPI.h"

// Airbridge
#import "AirBridge.h"
// AB
#import "AFLGet.h"

@interface AFLDeeplinkAPI () <FlutterStreamHandler>

@end

@implementation AFLDeeplinkAPI

static NSString* initialDeeplink;

+ (void) setInitialDeeplinkCallback {
    [AirBridge.deeplink setDeeplinkCallback:^(NSString* deeplink) {
        initialDeeplink = deeplink;
    }];
}

//
// flutter plugin setting
//

+ (void) registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
    AFLDeeplinkAPI* deeplinkAPI = [[AFLDeeplinkAPI alloc] init];
    
    FlutterEventChannel* deeplinkEvent
    = [FlutterEventChannel eventChannelWithName:@"airbridge_flutter_sdk/event/deeplink"
                                binaryMessenger:registrar.messenger];
    [deeplinkEvent setStreamHandler:deeplinkAPI];
}

- (FlutterError *)onListenWithArguments:(id)arguments eventSink:(FlutterEventSink)events {
    NSString* target = [AFLGet type:NSString.class object:arguments];
    if (target == nil || events == nil) {
        return nil;
    }
    
    if ([target isEqualToString:@"deeplink"]) {
        if (initialDeeplink != nil) {
            events(initialDeeplink);
            initialDeeplink = nil;
        }

        [AirBridge.deeplink setDeeplinkCallback:^(NSString* deeplink) {
            events(deeplink);
        }];
    }
    
    return nil;
}

- (FlutterError *)onCancelWithArguments:(id)arguments {
    NSString* target = [AFLGet type:NSString.class object:arguments];
    if (target == nil) {
        return nil;
    }
    
    if ([target isEqualToString:@"deeplink"]) {
        [AirBridge.deeplink setDeeplinkCallback:^(NSString* deeplink) {}];
    }
    
    return nil;
}

@end
